@@ -1,7 +1,6 @@
 #!/usr/bin/env python3
 # Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved
 
-from .dp_ddp import DifferentiallyPrivateDistributedDataParallel
 from .dp_multihead_attention import DPMultiheadAttention, SequenceBias
 from .dp_rnn import DPGRU, DPLSTM, DPRNN
 from .param_rename import RenameParamsMixin
@@ -14,5 +13,4 @@ __all__ = [
     "DPMultiheadAttention",
     "RenameParamsMixin",
     "SequenceBias",
-    "DifferentiallyPrivateDistributedDataParallel",
 ]
