@@ -14,6 +14,7 @@ class SequenceBias_test(GradSampleHooks_test):
         N=st.integers(1, 4),
         T=st.integers(10, 20),
         D=st.integers(4, 8),
+        batch_first=st.booleans(),
     )
     @settings(deadline=10000)
     def test_batch_second(
@@ -21,8 +22,12 @@ class SequenceBias_test(GradSampleHooks_test):
         N: int,
         T: int,
         D: int,
+        batch_first: bool,
     ):
 
-        seqbias = SequenceBias(D)
-        x = torch.randn([T, N, D])
-        self.run_test(x, seqbias, batch_first=False)
+        seqbias = SequenceBias(D, batch_first)
+        if batch_first:
+            x = torch.randn([N, T, D])
+        else:
+            x = torch.randn([T, N, D])
+        self.run_test(x, seqbias, batch_first)
